@@ -1,10 +1,13 @@
 import logging
+from typing import Optional, List
 
 from aiologger.loggers.json import JsonLogger
 from pydantic import BaseSettings
 
 from asyncworker.options import DefaultValues
 
+INFINITY = float("inf")
+
 
 class Settings(BaseSettings):
     LOGLEVEL: str = "ERROR"
@@ -18,6 +21,22 @@ class Settings(BaseSettings):
 
     FLUSH_TIMEOUT: int = DefaultValues.BULK_FLUSH_INTERVAL
 
+    # metrics
+    METRICS_NAMESPACE: str = "asyncworker"
+    METRICS_APPPREFIX: Optional[str]
+    METRICS_ROUTE_PATH: str = "/metrics"
+    METRICS_ROUTE_ENABLED: bool = True
+    METRICS_DEFAULT_HISTOGRAM_BUCKETS_IN_MS: List[float] = [
+        10,
+        50,
+        100,
+        200,
+        500,
+        1000,
+        5000,
+        INFINITY,
+    ]
+
     class Config:
         allow_mutation = False
         env_prefix = "ASYNCWORKER_"
