@@ -1,6 +1,6 @@
 import abc
 import collections
-from collections import KeysView, ValuesView
+from collections.abc import KeysView, ValuesView
 from typing import (
     Optional,
     Union,
