@@ -16,10 +16,10 @@ from aiohttp import web
 from aiohttp.hdrs import METH_ALL
 from aiohttp.web_routedef import RouteDef
 from cached_property import cached_property
-from pydantic import BaseModel, validator
+from pydantic import Extra, BaseModel, validator, root_validator
 
-from asyncworker.conf import settings
-from asyncworker.connections import AMQPConnection
+from asyncworker import conf
+from asyncworker.connections import Connection, AMQPConnection
 from asyncworker.http.wrapper import RequestWrapper
 from asyncworker.options import DefaultValues, RouteTypes, Actions
 from asyncworker.types.registry import TypesRegistry
@@ -51,10 +51,10 @@ class Model(BaseModel, abc.ABC):
         return super(Model, self).__eq__(other)
 
     def __len__(self):
-        return len(self.fields)
+        return len(self.__fields__)
 
     def keys(self):
-        return self.fields.keys()
+        return self.__fields__.keys()
 
     def get(self, key, default=None):
         try:
@@ -75,6 +75,7 @@ class Route(Model, abc.ABC):
     type: RouteTypes
     handler: Any
     routes: List[str]
+    connection: Optional[Connection]
     options: _RouteOptions = _RouteOptions()
 
     @staticmethod
@@ -88,8 +89,6 @@ class Route(Model, abc.ABC):
             return HTTPRoute(**data)
         if type_ == RouteTypes.AMQP_RABBITMQ:
             return AMQPRoute(**data)
-        if type_ == RouteTypes.SSE:
-            return SSERoute(**data)
         raise ValueError(f"'{type_}' is an invalid RouteType.")
 
 
@@ -113,6 +112,25 @@ class HTTPRoute(Route):
 
         return [cls._validate_method(method) for method in v]
 
+    @root_validator
+    def _validate_metrics_route(cls, values: dict) -> dict:
+        if not conf.settings.METRICS_ROUTE_ENABLED:
+            return values
+        if "methods" not in values:
+            return values
+        if "GET" not in values["methods"]:
+            return values
+        if conf.settings.METRICS_ROUTE_PATH in values["routes"]:
+            raise ValueError(
+                f"Conflicting HTTP routes."
+                f"Defining a `{conf.settings.METRICS_ROUTE_PATH}` "
+                f"conflicts with asyncworker's metrics path. Consider the "
+                f"following options: a) Remove your route and use asyncworker "
+                f"metrics; b) disable asyncworker's metrics route "
+            )
+
+        return values
+
     def aiohttp_routes(self) -> Iterable[RouteDef]:
         for route in self.routes:
             for method in self.methods:
@@ -125,7 +143,7 @@ class HTTPRoute(Route):
                 )
 
 
-class _AMQPRouteOptions(_RouteOptions):
+class AMQPRouteOptions(_RouteOptions):
     bulk_size: int = DefaultValues.BULK_SIZE
     bulk_flush_interval: int = DefaultValues.BULK_FLUSH_INTERVAL
     on_success: Actions = DefaultValues.ON_SUCCESS
@@ -136,54 +154,29 @@ class _AMQPRouteOptions(_RouteOptions):
     connection: Optional[Union[AMQPConnection, str]]
 
     class Config:
-        arbitrary_types_allowed = True
+        arbitrary_types_allowed = False
+        extra = Extra.forbid
 
 
 class AMQPRoute(Route):
     type: RouteTypes = RouteTypes.AMQP_RABBITMQ
-    vhost: str = settings.AMQP_DEFAULT_VHOST
-    options: _AMQPRouteOptions
+    vhost: str = conf.settings.AMQP_DEFAULT_VHOST
+    connection: Optional[AMQPConnection]
+    options: AMQPRouteOptions
 
 
-class _SSERouteOptions(_RouteOptions):
-    bulk_size: int = DefaultValues.BULK_SIZE
-    bulk_flush_interval: int = DefaultValues.BULK_FLUSH_INTERVAL
-    headers: Dict[str, str] = {}
-
-
-class SSERoute(Route):
-    type: RouteTypes = RouteTypes.SSE
-    headers: Dict[str, str] = {}
-    options: _SSERouteOptions = _SSERouteOptions()
-
-    @validator("options", pre=True, whole=True, always=True)
-    def add_default_headers(cls, v, values, **kwargs):
-        headers = {
-            **values.pop("headers", {}),
-            **values.pop("default_options", {}).get("headers", {}),
-        }
-        v["headers"] = headers
-
-        return v
-
-
-async def call_http_handler(request: web.Request, handler: RouteHandler):
-    """
-    Quando o RequestWrapper estiver mais sólido, esse método deve receber `asyncworker.http.wrapper.RequestWrapper` e não `web.Request`.
-    Primeiro vamos documentar que essa chamada será depreciada e função de chamada onde
-    recebemos `RequestWrapper`.
-    """
-    arg_resolver = ArgResolver(registry=request["types_registry"])
+async def call_http_handler(request: RequestWrapper, handler: RouteHandler):
+    arg_resolver = ArgResolver(registry=request.types_registry)
     try:
         return await arg_resolver.wrap(handler)
     except MissingTypeAnnotationError:
-        return await handler(request)
+        raise
 
 
 def http_handler_wrapper(handler):
     async def _insert_types_registry(request: web.Request):
         """
-        Esse é o único ponto que tem contato direto com o aiohttp. É essa corotina que é efetivament registrada nas rotas do aiohttp. Daqui pra frente tudo é chamado através do ccall_http_handler() e pode receber `RequestWrapper` como parametro.
+        Esse é o único ponto que tem contato direto com o aiohttp. É essa corotina que é efetivament registrada nas rotas do aiohttp. Daqui pra frente tudo é chamado através do ccall_http_handler().
         """
         registry = TypesRegistry()
         request["types_registry"] = registry
@@ -193,7 +186,7 @@ def http_handler_wrapper(handler):
             http_request=request, types_registry=registry
         )
         registry.set(r_wrapper)
-        return await call_http_handler(request, handler)
+        return await call_http_handler(r_wrapper, handler)
 
     return _insert_types_registry
 
@@ -210,10 +203,6 @@ class RoutesRegistry(UserDict):
     def amqp_routes(self) -> Iterable[AMQPRoute]:
         return self._get_routes_for_type(AMQPRoute)
 
-    @cached_property
-    def sse_routes(self) -> Iterable[SSERoute]:
-        return self._get_routes_for_type(SSERoute)
-
     def __setitem__(self, key: RouteHandler, value: Union[Dict, Route]):
 
         if not isinstance(value, Route):
@@ -229,5 +218,11 @@ class RoutesRegistry(UserDict):
     def add_route(self, route: Route) -> None:
         self[route.handler] = route
 
+    def add_http_route(self, route: HTTPRoute) -> None:
+        self[route.handler] = route
+
+    def add_amqp_route(self, route: AMQPRoute) -> None:
+        self[route.handler] = route
+
     def route_for(self, handler: RouteHandler) -> Route:
         return self[handler]
